@@ -1,6 +1,6 @@
 from pydantic import BaseModel, Field
 
-from unique_toolkit.tools.config import get_configuration_dict
+from unique_toolkit.agentic.tools.config import get_configuration_dict
 
 
 class FeatureExtendedSourceSerialization(BaseModel):
